<?php if (!defined('ABSPATH')) die;

define('PIPDIG_P3_V', '6.0.0');
define('PIPDIG_P3_DIR', dirname(__FILE__).'/');

function pipdig_switch_theme() {
	delete_transient('pipdig_active');
	delete_transient('pipdig_check_now_yeah');
	delete_transient('pipdig_check_theme_updates');
	delete_transient('p3_stats_gen');
	delete_option('pipdig_theme');
}
add_action('switch_theme', 'pipdig_switch_theme', 10);

// Download PO/MO translation files
/*
function p3_setup_languages() {

	if (
	(count(get_available_languages()) === 0) && 
	!defined('LOCO_LANG_DIR') && 
	!defined('WPML_TM_VERSION') && 
	!defined('WPGLOBUS_VERSION') &&
	!is_multisite()
	) {
		return;
	}
	
	if (!defined('P3_NO_LANG_DOWNLOAD') && !file_exists(get_template_directory().'/inc/functions/languages/translations.pot')) {
		require_once(ABSPATH.'wp-admin/includes/admin.php');
		if (!function_exists('WP_Filesystem')) {
			return;
		}
		WP_Filesystem();
		if (!class_exists('ZipArchive')) {
			return;
		}
		$url = 'https://wpupdateserver.com/v2/p3_lang.zip';
		$temp_file = download_url($url, 30);
		if (!is_wp_error($temp_file) && is_file($temp_file)) {
			$unzip = unzip_file($temp_file, get_template_directory().'/inc/functions/languages');
			unlink($temp_file);
		}
	}
	
}
add_action('init', 'p3_setup_languages');
*/

function p3_license_notification() {

	if (!is_super_admin()) {
		return;
	}

	if (is_pipdig_active()) {
		return;
	} else {

		$msg = '';
		if (!empty($_POST['p3_license_data'])) {
			
			if (!wp_verify_nonce($_POST['p3_license_nonce_field'], 'p3_license_nonce_action')) {
        		return;
        	}
			
			delete_transient('pipdig_active');
			$theme = get_option('pipdig_theme');
			$key = sanitize_text_field($_POST['p3_license_data']);
			if (is_numeric($key)) {
				$msg = '<p style="font-weight: bold; font-size: 15px;">The key "'.$key.'" could not be validated. Please note that the license key is not the same as your order number. If you need any help finding your key please see the steps on <a href="https://go.pipdig.co/open.php?id=license-help" target="_blank" rel="noopener">this page</a>.</p>';
			} elseif (is_pipdig_active($key, true)) {
				update_option($theme.'_key', $key);
				return;
			} else {
				$msg = '<p style="font-weight: bold; font-size: 15px;">The key "'.$key.'" could not be validated. Please try again to double check. You can get help finding your license key on <a href="https://go.pipdig.co/open.php?id=license-help" target="_blank" rel="noopener">this page</a>.</p>';
			}
		} else {
			$key = '';
		}

		?>
		<div class="notice notice-warning">
			<h2><span class="dashicons dashicons-warning"></span> Action required</h2>
			<p>To ensure all features of your pipdig theme are active, please enter your pipdig theme license key below.</p>
			<p>Please see <a href="https://go.pipdig.co/open.php?id=license-help" target="_blank" rel="noopener">this page</a> for more information.</p>
			<p>Enter your license key below:</p>
			<?php echo $msg; ?>
			<form action="" method="post" autocomplete="off">
				<?php wp_nonce_field('p3_license_nonce_action', 'p3_license_nonce_field'); ?>
				<input type="text" value="<?php echo $key; ?>" name="p3_license_data" />
				<p class="submit" style="margin-top: 5px; padding-top: 5px;">
					<input name="submit" class="button" value="Validate Key" type="submit" />
				</p>
			</form>
		</div>
		<?php

	}

}
add_action('admin_notices', 'p3_license_notification');

function is_pipdig_active($key = '', $cb = false) {
	
	$me = get_site_url();
	
	if (strpos($me, '127.0.0.1') !== false) {
		return 1;
	} elseif (strpos($me, '.local') !== false) {
		return 1;
	} elseif (strpos($me, 'localhost') !== false) {
		return 1;
	} elseif (strpos($me, '/~') !== false) {
		return 1;
	}
	
	if (false === ($active = get_transient('pipdig_active'))) {

		$pipdig_id = get_option('pipdig_id');
		if (!$pipdig_id) {
			$pipdig_id = sanitize_text_field(substr(str_shuffle(MD5(microtime())), 0, 10));
			add_option('pipdig_id', $pipdig_id);
		}

		$active = 0;
		$request_array = array();

		$theme = get_option('pipdig_theme');
		if (!$theme) {
			return 0;
		}

		if (!$key) {
			$key = get_option($theme.'_key');
			if (empty($key)) {
				return 0;
			}
		}

		$request_array['domain'] = get_site_url();
		$request_array['id'] = $pipdig_id;
		$request_array['key'] = $key;
		$request_array['theme'] = $theme;
		if ($cb) {
			$request_array['cb'] = date('i');
		}

		$url = add_query_arg($request_array, 'https://wptagname.space/');
		$args = array(
		    'timeout' => 10,
		);
		$init = wp_remote_get($url, $args);
		$version = absint(wp_remote_retrieve_response_code($init));
		if ($version === 200) {
			$result = absint(wp_remote_retrieve_body($init));
			if ($result === 1 || $result === 2 || $result === 3) {
				$active = 1;
			} else {
				$active = 0;
			}
		}

		if ($active) {
			set_transient('pipdig_active', $active, 3 * WEEK_IN_SECONDS);
		} else {
			set_transient('pipdig_active', $active, 1 * HOUR_IN_SECONDS);
		}

	}

	return $active;
}

// enqueue scripts and styles
function pipdig_p3_scripts_styles() {

	if (get_theme_mod('disable_responsive')) {
		wp_enqueue_style('p3-core', 'https://pipdigz.co.uk/p3/css/core.css', array(), null);
	} else {
		wp_enqueue_style('p3-core-responsive', 'https://pipdigz.co.uk/p3/css/core_resp.css', array(), null);
	}
	
	/*
	if (!function_exists('pipdig_previews_pipdigicons')) {
		wp_enqueue_style('pipdigicons', 'https://pipdigz.co.uk/fonts/pipdigicons.css', array(), null);
	}
	*/
	
	if (is_child_theme()) {
		wp_enqueue_script('pipdigicons-migrate-2', 'https://pipdigz.co.uk/p3/js/icons_migrate_2.js', array('jquery'), PIPDIG_P3_V, true);
	}
	
	wp_register_script('pipdig-imagesloaded', 'https://cdnjs.cloudflare.com/ajax/libs/jquery.imagesloaded/4.1.4/imagesloaded.pkgd.min.js', array('jquery'), null, false);
	wp_register_script('pipdig-masonry', 'https://cdnjs.cloudflare.com/ajax/libs/masonry/4.2.1/masonry.pkgd.min.js', array('pipdig-imagesloaded'), null, false);
	wp_register_script('pipdig-cycle', 'https://cdnjs.cloudflare.com/ajax/libs/jquery.cycle2/20140415/jquery.cycle2.min.js', array('jquery'), null, true);
	wp_register_script('pipdig-cycle-swipe', 'https://cdnjs.cloudflare.com/ajax/libs/jquery.cycle2/20140415/jquery.cycle2.swipe.min.js', array('jquery'), null, true);
	wp_register_script('jquery-easing', 'https://cdnjs.cloudflare.com/ajax/libs/jquery-easing/1.4.1/jquery.easing.min.js', array('jquery'), null, true);
	wp_register_script('pipdig-owl', 'https://cdnjs.cloudflare.com/ajax/libs/owl-carousel/1.3.3/owl.carousel.min.js', array('jquery'), null, false);
	wp_register_script('backstretch', 'https://cdnjs.cloudflare.com/ajax/libs/jquery-backstretch/2.0.4/jquery.backstretch.min.js', array('jquery'), null, false);
	wp_register_script('stellar', 'https://cdnjs.cloudflare.com/ajax/libs/stellar.js/0.6.2/jquery.stellar.min.js', array('jquery'), null, true);
	wp_register_script('rateyo', 'https://cdnjs.cloudflare.com/ajax/libs/rateYo/2.1.1/jquery.rateyo.min.js', array('jquery'), null, true);
	wp_enqueue_script('pipdig-fitvids', 'https://cdnjs.cloudflare.com/ajax/libs/fitvids/1.2.0/jquery.fitvids.min.js', array('jquery'), null, true);
	wp_register_script('pipdig-mixitup', 'https://cdnjs.cloudflare.com/ajax/libs/mixitup/2.1.11/jquery.mixitup.min.js', array('jquery'), null, true);
	wp_register_script('pipdig-flickity', 'https://cdnjs.cloudflare.com/ajax/libs/flickity/2.2.0/flickity.pkgd.min.js', array('jquery'), null, false);
	wp_register_script('pipdig-flickity-bglazy', 'https://unpkg.com/flickity-bg-lazyload@1.0.1/bg-lazyload.js', array('pipdig-flickity'), null, false);
	if (is_pipdig_lazy()) { 
		wp_enqueue_script('pipdig-lazy', 'https://cdnjs.cloudflare.com/ajax/libs/jquery.lazy/1.7.9/jquery.lazy.min.js', array('jquery'), null, true);
	}

}
add_action('wp_enqueue_scripts', 'pipdig_p3_scripts_styles');


function pipdigicons_assets() {
	if (function_exists('pipdig_previews_pipdigicons')) {
		return;
	}
	?>
	<link rel="stylesheet" href="https://pipdigz.co.uk/fonts/pipdigicons_2.css" media="none" onload="if(media!='all')media='all'">
	<?php
}
add_action('wp_footer', 'pipdigicons_assets', 99999999);

include_once('inc/functions.php');
include_once('inc/admin-menus.php');
include_once('inc/meta.php');
include_once('inc/dash.php');
include_once('inc/widgets.php');
include_once('inc/shortcodes.php');
include_once('inc/beaver.php');

include_once (ABSPATH.'wp-admin/includes/plugin.php');
if (!is_plugin_active('jetpack/jetpack.php')) {
	// widget visibility
	if (!class_exists('Jetpack_Widget_Conditions')) {
		include_once('inc/bundled/widget-visibility/widget-conditions.php');
	}
} else {
	include_once('inc/jetpack.php');
}

function p3_new_install_notice() {
	
	global $pagenow;
	if ($pagenow != 'index.php' && $pagenow != 'themes.php') {
		return;
	}

	if (isset($_GET['page']) && $_GET['page'] == 'pipdig-demo-import') {
		return;
	}

	if (current_user_can('manage_options')) {
		if (isset($_POST['p3_new_install_notice_dismissed'])) {
			update_option('p3_new_install_notice', 1);
			return;
		}
	}

	if (get_option('p3_new_install_notice') || !current_user_can('manage_options')) {
		return;
	}

	if (!is_pipdig_active()) {
		return;
	}

	$import = $wp101 = '';
	$posts = wp_count_posts();
	$posts_count = $posts->publish + $posts->draft;
	if ($posts_count < 4) {
		
		$classic = '';
		if (class_exists('Classic_Editor')) {
			$classic = 'classic';
		}
		
		$import = '<p>Is this a new site? You might like to <a href="'.admin_url('admin.php?page=pipdig-import-demo').'">import some demo posts and pages</a>.</p>';
		$wp101 = '<p>New to WordPress? You can access the premium series of WP101 Tutorials on <a href="https://go.pipdig.co/open.php?id=wp101videos'.$classic.'" target="_blank" rel="noopener">this page</a>.</p>';
	}
	
	?>
	<div class="notice notice-warning">
		<h2><?php _e('Howdy!', 'p3'); ?></h2>
		<p>Thank you for installing a pipdig theme!</p>
		<p>You can now setup all of our custom widgets, options and features using our <a href="https://go.pipdig.co/open.php?id=wp-quickstart" target="_blank">Quickstart Guide</a>.</p>
		<?php echo $wp101; ?>
		<?php echo $import; ?>
		<form action="<?php echo esc_url(admin_url($pagenow)); ?>" method="post">
			<input type="hidden" value="true" name="p3_new_install_notice_dismissed" />
			<p class="submit" style="margin-top: 5px; padding-top: 5px;">
				<input name="submit" class="button" value="Hide this notice" type="submit" />
			</p>
		</form>
	</div>
	<?php
}
add_action('admin_notices', 'p3_new_install_notice');

function p3_theme_update_notice() {
	
	if (is_multisite()) {
		return;
	}
	
	global $pagenow;
	if ($pagenow == 'update-core.php' || $pagenow == 'themes.php') {
		delete_transient('pipdig_check_theme_updates');
	} elseif ($pagenow != 'index.php') {
		return;
	}
	
	if (false === ($result = get_transient('pipdig_check_theme_updates'))) {
		$request_array = array();
		$request_array['type'] = 'theme';
		$request_array['action'] = 'get_metadata';
		$request_array['slug'] = sanitize_text_field(get_template());
		$request_array['key'] = 'none';
		$request_array['p3_theme_v_check'] = '1';
		$url = add_query_arg($request_array, 'https://wpupdateserver.com/v2/');
		$args = array(
		    'timeout' => 10,
		);

		$response = wp_remote_retrieve_body(wp_remote_get($url, $args));

		if ($response) {
			$result = json_decode($response);
		} else {
			return;
		}
		
		set_transient('pipdig_check_theme_updates', $result, 12 * HOUR_IN_SECONDS);
	}
	
	if (empty($result->version)) {
		return;
	}
	
	
	$latest_ver = $result->version;
	
	$theme = wp_get_theme(get_template());
	$this_ver = $theme->get('Version');
	
	if ($this_ver === $latest_ver) {
		return;
	}
	
	/*
	$slug = sanitize_text_field(get_template());
	
	$more_info = 'https://wpupdateserver.com/v2/changelog.php?id='.$slug.'&current='.$this_ver;
	if (!empty($result->details_url)) {
		$more_info = $result->details_url.'&current='.$this_ver;
	}
	*/
	
	if (is_super_admin()) {
		$msg = '<p>Please complete the updates on <a href="'.admin_url('update-core.php').'">this page</a>. If no updates are showing on that page, please update manually via <a href="https://support.pipdig.co/articles/wordpress-manually-update-theme/" rel="noopener" target="_blank">this guide</a>.</p>';
	} else {
		$msg = '<p>Please ask the person which manages your website to update the theme via <a href="https://support.pipdig.co/articles/wordpress-how-to-update-your-theme/" rel="noopener" target="_blank">this guide</a>.</p>';
	}
	
	?>
	<div id="pipdig_theme_update_notice" class="notice notice-success">
		<p><span class="dashicons dashicons-star-filled"></span> Howdy! An update is available for your pipdig theme. <?php echo $msg; ?></p>
	</div>
	<?php
}
add_action('admin_notices', 'p3_theme_update_notice');

require_once 'inc/plugin-update-checker/plugin-update-checker.php';